.. include:: ../README.rst

API documentation
=================
.. automodule:: cromwell_tools.cromwell_api
   :members:
   :inherited-members:

.. automodule:: cromwell_tools.cromwell_auth
   :members:
   :inherited-members:

.. automodule:: cromwell_tools.utilities
   :members:
   :inherited-members:

.. automodule:: cromwell_tools.cli
   :members:
   :inherited-members:

Table of Contents
=================
.. toctree::
   :maxdepth: 4


* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
